/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.oauth2.provider.scope.internal.liferay;

import com.liferay.oauth2.provider.scope.internal.constants.OAuth2ProviderScopeConstants;
import com.liferay.oauth2.provider.scope.liferay.ScopeDescriptorLocator;
import com.liferay.oauth2.provider.scope.spi.scope.descriptor.ScopeDescriptor;
import com.liferay.osgi.service.tracker.collections.map.ServiceTrackerMap;
import com.liferay.osgi.service.tracker.collections.map.ServiceTrackerMapFactory;

import org.osgi.framework.BundleContext;
import org.osgi.service.component.annotations.Activate;
import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Deactivate;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Carlos Sierra Andrés
 */
@Component
public class ScopeDescriptorLocatorImpl implements ScopeDescriptorLocator {

	@Override
	public ScopeDescriptor getScopeDescriptor(String applicationName) {
		ScopeDescriptor scopeDescriptor =
			_scopeDescriptorsByApplicationName.getService(applicationName);

		if (scopeDescriptor == null) {
			return _defaultScopeDescriptor;
		}

		return scopeDescriptor;
	}

	@Activate
	protected void activate(BundleContext bundleContext) {
		_scopeDescriptorsByApplicationName =
			ServiceTrackerMapFactory.openSingleValueMap(
				bundleContext, ScopeDescriptor.class,
				OAuth2ProviderScopeConstants.OSGI_JAXRS_NAME);
		_scopeDescriptorsByCompany =
			ServiceTrackerMapFactory.openSingleValueMap(
				bundleContext, ScopeDescriptor.class, "company.id");
	}

	@Deactivate
	protected void deactivate() {
		_scopeDescriptorsByApplicationName.close();

		_scopeDescriptorsByCompany.close();
	}

	@Reference(target = "(default=true)")
	private ScopeDescriptor _defaultScopeDescriptor;

	private ServiceTrackerMap<String, ScopeDescriptor>
		_scopeDescriptorsByApplicationName;
	private ServiceTrackerMap<String, ScopeDescriptor>
		_scopeDescriptorsByCompany;

}